@@ -65,7 +65,7 @@ elif dpkg-architecture -iany-amd64; then
 	fi
 	ROOTFINDER=asmgcc
 fi
-RPYOPTS="$RPYOPTS --opt=$OPT"
+RPYOPTS="$RPYOPTS --opt=$OPT --no-shared"
 
 if [ $SANDBOX -gt 0 ]; then
 	RPYOPTS="$RPYOPTS --sandbox --gc=generation"
